@@ -167,10 +167,18 @@ verify_date (GtkWidget *entry, GdkEventFocus *event, GtkDateCombo *cb)
   const gchar *text = gtk_entry_get_text (GTK_ENTRY (entry));
   struct tm time;
   char *ret;
-    
+  
+  if (!strlen(text)) /* allow empty text */
+    {
+      cb->set = FALSE;
+      return FALSE;
+    }
   ret = strptime (text, "%x", &time);
   if (ret)
-    gtk_date_combo_set_date (cb, time.tm_year+1900, time.tm_mon, time.tm_mday);
+    {
+      gtk_date_combo_set_date (cb, time.tm_year+1900, time.tm_mon, time.tm_mday);
+      cb->set = TRUE;
+    }
   else
     update_text (cb);
 
